# UPF to JSON converter

UPF is a file format to describe atomic pseudo-potentials used by (DFT) density
functional theory codes. This package provides scripts for converting UPF v1 and
UPF v2 (Unified Pseudopotential Format) to json format as required by the SIRIUS
DFT library [SIRIUS github](https://github.com/electronic-structure/SIRIUS).


More information about the unified pseudopotential format can be found here:
https://www.quantum-espresso.org/pseudopotentials/unified-pseudopotential-format
